import NDK, {NDKEvent, NDKPrivateKeySigner, NDKUser} from "@nostr-dev-kit/ndk";
import {generateSecretKey} from "nostr-tools";
import {randomTimeUpTo2DaysInThePast} from "./general.ts";
import {decode as nip19Decode, npubEncode} from "nostr-tools/nip19";

export async function encryptEventForRecipient(
  ndk: NDK,
  event: NDKEvent,
  recipient: NDKUser
): Promise<NDKEvent> {
  await ndk.connect();
  let randomKey = generateSecretKey();
  const randomKeySinger = new NDKPrivateKeySigner(randomKey);
  const seal = new NDKEvent();
  seal.pubkey = recipient.pubkey;
  seal.kind = 13;
  seal.content = await ndk.signer!.nip44Encrypt(recipient, JSON.stringify(event));
  seal.created_at = randomTimeUpTo2DaysInThePast();
  await seal.sign(ndk.signer);
  const giftWrap = new NDKEvent();
  giftWrap.kind = 1059;
  giftWrap.created_at = randomTimeUpTo2DaysInThePast();
  giftWrap.content = await randomKeySinger.nip44Encrypt(recipient, JSON.stringify(seal));
  giftWrap.tags.push(['p', recipient.pubkey]);
  await giftWrap.sign(randomKeySinger);
  giftWrap.ndk = ndk;
  return giftWrap;
}

export function npubToPubKeyString(npub: string) {
  const decoded = nip19Decode(npub);
  if (decoded.type !== 'npub')
    throw new Error('Invalid npub');
  return decoded.data;
}

export function pubKeyStringToNpub(pubKey: string) {
  return npubEncode(pubKey);
}
